@@ -4,7 +4,7 @@
 # Pod stripped from pm file by OODoc 2.00.
 package Log::Report::Translator;
 use vars '$VERSION';
-$VERSION = '0.95';
+$VERSION = '0.96';
 
 
 use warnings;
@@ -15,6 +15,7 @@ use File::Spec ();
 use Log::Report 'log-report', syntax => 'SHORT';
 
 use Log::Report::Lexicon::Index ();
+use Log::Report::Message;
 
 my %lexicons;
 
@@ -67,4 +68,26 @@ sub translate($)
 
 sub load($@) { undef }
 
+
+sub TemplateToolkit($$$;$@)
+{   my ($self, $domain, $lang, $msgid) = splice @_, 0, 4;
+    my $plural = $msgid =~ s/\|(.*)// ? $1 : undef;
+    my $args   = @_ && ref $_[-1] eq 'HASH' ? pop : {};
+
+    my $count;
+    if(defined $plural)
+    {   @_==1 or $msgid .= " (ERROR: missing count for plural)";
+        $count = shift;
+    }
+    else
+    {   @_==0 or $msgid .= " (ERROR: only named parameters expected)";
+    }
+
+    my $msg = Log::Report::Message->new
+        ( _msgid => $msgid, _plural => $plural, _count => $count
+        , %$args, _expand => 1, _domain => $domain);
+
+    $self->translate($msg, $lang);
+}
+
 1;
